@@ -3,9 +3,9 @@ from django.utils.decorators import method_decorator
 from allauth.account.adapter import get_adapter as get_account_adapter
 from allauth.account.internal import flows
 from allauth.account.internal.flows import password_change, password_reset
-from allauth.account.models import EmailAddress, Login
+from allauth.account.models import EmailAddress
 from allauth.account.stages import EmailVerificationStage, LoginStageController
-from allauth.account.utils import complete_signup, send_email_confirmation
+from allauth.account.utils import send_email_confirmation
 from allauth.core import ratelimit
 from allauth.core.exceptions import ImmediateHttpResponse
 from allauth.decorators import rate_limit
@@ -56,8 +56,10 @@ class ConfirmLoginCodeView(APIView):
         if not self.stage:
             return ConflictResponse(request)
         self.user, self.pending_login = flows.login_by_code.get_pending_login(
-            self.stage.login, peek=True
+            request, self.stage.login, peek=True
         )
+        if not self.pending_login:
+            return ConflictResponse(request)
         return super().dispatch(request, *args, **kwargs)
 
     def post(self, request, *args, **kwargs):
@@ -84,16 +86,14 @@ class LoginView(APIView):
         if request.user.is_authenticated:
             return ConflictResponse(request)
         credentials = self.input.cleaned_data
-        user = get_account_adapter().authenticate(self.request, **credentials)
-        if user:
-            login = Login(user=user, email=credentials.get("email"))
-            flows.login.perform_password_login(request, credentials, login)
+        flows.login.perform_password_login(request, credentials, self.input.login)
         return AuthenticationResponse(self.request)
 
 
 @method_decorator(rate_limit(action="signup"), name="handle")
 class SignupView(APIView):
-    input_class = SignupInput
+    input_class = {"POST": SignupInput}
+    by_passkey = False
 
     def post(self, request, *args, **kwargs):
         if request.user.is_authenticated:
@@ -103,11 +103,8 @@ class SignupView(APIView):
         user, resp = self.input.try_save(request)
         if not resp:
             try:
-                complete_signup(
-                    request,
-                    user,
-                    email_verification=None,
-                    success_url=None,
+                flows.signup.complete_signup(
+                    request, user=user, by_passkey=self.by_passkey
                 )
             except ImmediateHttpResponse:
                 pass
