@@ -5,15 +5,12 @@ from allauth.socialaccount.providers.oauth2.views import (
     OAuth2LoginView,
 )
 
-from .provider import BitlyProvider
-
 
 class BitlyOAuth2Adapter(OAuth2Adapter):
-    provider_id = BitlyProvider.id
+    provider_id = "bitly"
     access_token_url = "https://api-ssl.bitly.com/oauth/access_token"
     authorize_url = "https://bitly.com/oauth/authorize"
     profile_url = "https://api-ssl.bitly.com/v3/user/info"
-    supports_state = False
 
     def complete_login(self, request, app, token, **kwargs):
         resp = (
